@@ -28,8 +28,9 @@ import sqlparse
 class _DbConnection(object):
     """Internal class for connecting to mysql server without connection pool present in MyDbUtil"""
 
-    def __init__(self, dbServer="mysql", dbHost="localhost", dbName=None, dbUser=None, dbPw=None,
-                 dbSocket=None, dbPort=None, verbose=False, log=sys.stderr):  # pylint: disable=unused-argument
+    def __init__(
+        self, dbServer="mysql", dbHost="localhost", dbName=None, dbUser=None, dbPw=None, dbSocket=None, dbPort=None, verbose=False, log=sys.stderr
+    ):  # pylint: disable=unused-argument
         self.__lfh = log
 
         self.__dbName = dbName
